agentle.agents.whatsapp.models.audio\_message
=============================================

.. automodule:: agentle.agents.whatsapp.models.audio_message

   
   .. rubric:: Functions

   .. autosummary::
   
      TypedDict
   
   .. rubric:: Classes

   .. autosummary::
   
      AudioMessage
   